# 1.2.3 (11 Dec 2022)
- fix always passed tests
- add a few tests

# 1.2.2 (10 Dec 2022)
- add default\_cc to hook's parsing
- move to cmake
- add test system

# 1.2.1 (9 Dec 2022)
- refix indents
- add injections via segments

# 1.2.0 (29 Oct 2022)
## Changes
- add -fPIC when compiling libtarget.so
- some black formating
- fix indents in translation.c
- fix problem with wrong .text offset

# 1.2 (16 Oct 2022)
## Changes
- switch from \_\_LINE\_\_ to \_\_COUNTER\_\_ in definition of imported func

# 1.1 (15 Oct 2022)
## Changes
- add changelog
- fix multiple call imported function error
- add ability to get return from import function
- add debug logs
- fix section create bug
- add common errors note
- PyPi structure

# 1.0
Public release
